from setuptools import setup

setup(
	name='downloaderlib',
    version='2.1',
    description='This library is for downloading images, GitHub files, etc.',
    packages=['downloaderlib'],
   author_email='0nameofshadow0@gmail.com',
    install_requires=["urllib3","requests"])


from requests import get
from os import mkdir

class downloader:
	namedir = "Download"
	def picture(link, namedir=namedir):
		try:
			mkdir(namedir)
			name = link.split("/")[-1]
			r = get(link, allow_redirects=True)
			open(f"{namedir}/picture-{name}", "wb").write(r.content)
		except FileExistsError:
			name = link.split("/")[-1]
			r = get(link, allow_redirects=True)
			open(f"{namedir}/picture-{name}", "wb").write(r.content)
	def code(link, namedir=namedir):
		try:
			mkdir(namedir)
			name = link.split("/")[-1]
			r = get(link, allow_redirects=True)
			open(f"{namedir}/code-{name}", "wb").write(r.content)
		except FileExistsError:
			name = link.split("/")[-1]
			r = get(link, allow_redirects=True)
			open(f"{namedir}/code-{name}", "wb").write(r.content)
	def music(link, namedir=namedir):
		try:
			mkdir(namedir)
			name = link.split("/")[-1]
			r = get(link, allow_redirects=True)
			open(f"{namedir}/music-{name}", "wb").write(r.content)
		except FileExistsError:
			name = link.split("/")[-1]
			r = get(link, allow_redirects=True)
			open(f"{namedir}/music-{name}", "wb").write(r.content)
	def youtube_video(link, namedir=namedir):
		pass